---
title: anthropic
sidebarTitle: anthropic
---

# `fastmcp.client.sampling.handlers.anthropic`


Anthropic sampling handler for FastMCP.

## Classes

### `AnthropicSamplingHandler` <sup><a href="https://github.com/PrefectHQ/fastmcp/blob/main/src/fastmcp/client/sampling/handlers/anthropic.py#L46" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>


Sampling handler that uses the Anthropic API.

